/*
    EMailAddress.cc
    Bowen Moursund
    Posted on the dBASE newsgroups, July 6, 2005

    This (non-visual) class attempts to validate an email address.

    	Update: 07.05.2006
      Winfried Schneller
      	New  
	      #define MEHR_ALS_ZWEI_LETTER_TLDS
         check more then 2 letters in TLD
         min 2 letters in TLD


    Usage:
       set procedure to :dUFLP:EMailAddress.cc additive
       oEMail = new EMailAddress()
       // check to see if valid:
       if not oEMail.isValid( <emailaddress> )
          msgbox( oEMail.ErrorMessage, "EMail Address Invalid", 16 )
          return
       endif
       // continue processing ...
*/

// if a character is valid in an email address and not shown here, add to the end of the list:
#define VALID_CHARS "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ@-_.'"
// Top-Level Domains -- with four letters -- add your own to this list with 
// a "|" symbol between, include the dot ("."), if you need a four-letter domain
// name to be considered valid (they are not common).
#define FOUR_LETTER_TLDS ".name|.info|.fake"

// Author Winfried Schneller
// Added new constant for additional check.
// Generally top level domains for countries consist of two characters.
// Now top level domains wider than two characters are checked also.
// Checking Top Level Domains with a length greater than two characters
// "More than two letter TLDs"
#define MEHR_ALS_ZWEI_LETTER_TLDS ".aero|.arpa|.biz|.com|.coop|.edu|.gov|.info|.int|.jobs|.mil|.mobi|.museum|.name|.net|.org|.pro|.travel"

// quelle 
//http://de.wikipedia.org/wiki/Top_Level_Domain
/*
.aero  aeronautics, fr in der Luftfahrt ttige Organisationen  weltweit 
.arpa  TLD des ursprnglichen Arpanets, jetzt verwendet als Address and Routing Parameter Area 
.biz  business, nur fr Firmen  weltweit 
.com  commercial, ursprnglich nur fr US-Firmen, jetzt frei fr jeden  weltweit (*) 
.coop  cooperatives (Genossenschaften) - weltweit 
.edu  educational, nur fr Bildungseinrichtungen (zum Beispiel www.mit.edu) (*) 
.gov  government, nur Regierungsorgane der USA (zum Beispiel www.whitehouse.gov) (*) 
.info  Informationsanbieter  weltweit 
.int  Internationale Regierungsorganisationen (zum Beispiel www.nato.int oder www.eu.int) 
.jobs - jobs, nur fr Firmen mit Stellenangeboten - weltweit 
.mil  military, nur fr militrische Einrichtungen der USA (zum Beispiel www.army.mil) (*) 
.mobi - mobile, Darstellung der Webseiten speziell fr mobile Endgerte, sTLD - weltweit 
.museum  Museen  weltweit 
.name  nur fr natrliche Personen oder Familien (Privatpersonen)  weltweit 
.net  Netzverwaltungseinrichtung  weltweit (*) 
.org  organization, ursprnglich fr nichtkommerzielle Organisationen reserviert, inzwischen allgemein freigegeben  weltweit (*) 
.pro  professions (Anwlte, Steuerberater, rzte, Ingenieure)  nur fr genannte Berufsgruppen der USA, Kanadas, Deutschlands und des Vereinigten Knigreichs 
.travel  fr die Reise-Industrie (z. B. Reisebros, Fluggesellschaften etc.) 
*/

class EmailAddress

  this.ErrorMessage = ""
  this.Address = ""

   function isValid( cAddress )
      if not empty( cAddress )
         this.Address = ltrim(trim( cAddress ))
         cAddress = this.Address
      else
         this.Address = ""
         cAddress = ""
      endif
      this.ErrorMessage = ""

      local bIsValid
      bIsValid = true

      // chk length
      if len( cAddress ) < 5
         // a@b.c should be the shortest an
         // address could be
         bIsValid := false
         this.ErrorMessage := "The email address is too short to be a valid address."

      // chk format
      // has at least one "@"
      elseif not "@" $ cAddress
         bIsValid := false
         this.ErrorMessage := "The email address does not contain the '@' character."

      // has at least one "."
      elseif not "." $ cAddress
         bIsValid := false
         this.ErrorMessage := "The email address does not contain the '.' character."

/*		OLD CHECK
      // has no more than 3 chars after last "."
      elseif len(cAddress)-rat(".", cAddress) > 3 and ;
             not (lower(substr(cAddress, rat(".",cAddress))) $ FOUR_LETTER_TLDS)
         bIsValid := false
         this.ErrorMessage := "The top level domain of the email address is unknown or of an invalid length, or you may have entered more than one email address."
*/

		//New WS 07.05.2006
      // has no 2 chars after last "."
      elseif len(cAddress)-rat(".", cAddress) < 2 
         bIsValid := false
         this.ErrorMessage := "The top level domain of the email address is unknown or of an invalid length, or you may have entered more than one email address."

		//New WS 07.05.2006
      // has no more than 2 chars after last "."
      elseif len(cAddress)-rat(".", cAddress) > 2 and ;
             not (lower(substr(cAddress, rat(".",cAddress))) $ MEHR_ALS_ZWEI_LETTER_TLDS)
         bIsValid := false
         this.ErrorMessage := "The top level domain of the email address is unknown or of an invalid length, or you may have entered more than one email address."


      // has no "_" after the "@"
      elseif rat( "_", cAddress ) > rat( "@", cAddress )
         bIsValid := false
         this.ErrorMessage := "The email address contains a '_' character after the '@'."

      // has only one "@"
      elseif at( "@", cAddress, 2 ) > 0
         bIsValid := false
         this.ErrorMessage := "The email address contains more than one '@' character."

      // has at least one character before the @
      elseif left( cAddress, 1 ) = "@"
         bIsValid := false
         this.ErrorMessage := "The email address does not specify a recipient - there are no characters before the '@'."

      else // chk each char for validity
         for i = 1 to len( cAddress )
             if not substr( cAddress, i, 1 ) $ VALID_CHARS
                bIsValid := false
                this.ErrorMessage := "The email address contains an invalid character: '" + substr( cAddress, i, 1 ) + "'"
                exit
             endif
         next

      endif

   return bIsValid
   // eom: isValid()
endclass
