// Metric:  0 - Chars or 6 - Pixels only
/*
    SelPrinterContainer
    Author: Ken Mayer
    Date..: August 16, 2002

    SelPrinterContainer is literally a container that 
    holds the PrinterListCombobox and a text control,
    so that both can be placed directly onto a form
    and used there.

    The combobox, if on this container, will set the value
    property to the container, so it can be gotten there:

    ? form.SelPrinterContainer1.printerName

    This is a bit simpler than:

    ? form.SelPrinterContainer1.PrinterListCombobox1.value

    To place this on a form:
       set procedure to :dUFLP:SelPrinter.cc additive

    In the form designer, go to the Custom tab, and drag this
    control from there to the design surface ...
*/
class SELPRINTERCONTAINER( oParent ) of CONTAINER( oParent ) custom
   with (this)
      transparent = true
      width = 47.7143
      height = 1.5
      metric = 0	// Chars
      borderStyle = 3	// None
   endwith

   this.PrinterListCombobox1 = new PRINTERLISTCOMBOBOX(this)
   with (this.PrinterListCombobox1)
      left = 14.4286
      top = 0.0909
   endwith

   this.TEXT1 = new TEXT(this)
   with (this.TEXT1)
      height = 0.6364
      left = 0
      top = 0.2273
      width = 13.7143
      alignVertical = 1	// Middle
      alignHorizontal = 2	// Right
      fontBold = true
      text = "Select Printer:"
      pageno = 0
   endwith

   function onDesignOpen( lFromPalette )
      if lFromPalette and form.metric == 6 // Pixels
         this.height                     :=  33
         this.width                      := 334
         this.Text1.height               :=  14
         this.Text1.left                 :=   0
         this.Text1.top                  :=   5
         this.Text1.width                :=  96
         this.PrinterListCombobox1.height :=  23
         this.PrinterListCombobox1.left   := 101
         this.PrinterListCombobox1.top    :=   2
         this.PrinterListCombobox1.width  := 225
      endif
   return

endclass

/*
    PrinterListCombobox
    Posted in the dbase.programming newsgroup by Jan Hoelterling,
    it is believed this may have been created by Rich (of AutoTraker).
    Put into a custom control by Ken Mayer for the dUFLP,
    August 16, 2002

    **** IMPORTANT: This uses the Windows Scripting Host,
    **** which is normally installed by default when you
    **** install Windows (98 or later -- this is not installed
    **** by default in Win 95, or NT -- you need to go to
    **** the Microsoft website and download it) -- if you do 
    **** NOT have it installed for some reason, or have uninstalled 
    **** it, this will not work!

    Can be used by itself or by using the SelPrinterContainer
    class above. If used by itself:

    set procedure to :dUFLP:SelPrinter.cc additive

    In the form designer drag an instance of PrinterListCombo to
    the design surface ...

    To get the selected printer, simply poll the combobox's value
    property:

       ? form.PrinterListCombobox1.value
*/
class PRINTERLISTCOMBOBOX(oParent) of COMBOBOX(oParent) custom
   with (this)
      onOpen = class::PRINTERLISTCOMBOBOX_ONOPEN
      onSelChange = class::ItChanged
      height = 1.0455
      width = 32.1429
      metric = 0	// Chars
      style = 2	// DropDownList
      sorted = true
   endwith

   function PRINTERLISTCOMBOBOX_onOpen
      private x, i, oPrinters
      // Create array
      this.avprinters = new array()
      // Create an Ole object, calling Windows Scripting Host (WSH)
      x = new OleAutoClient("WScript.Network")
      // Get list of printers
      oPrinters = x.EnumPrinterConnections()
      // assign printers to array
      for i = 0 to oPrinters.count() -1 step 2
          this.avprinters.add(oPrinters.Item(i+1))
      next i
      // set the dataSource to the array
      this.dataSource = "array this.avPrinters"
      // set the combobox default to the default printer for Windows
      this.value := right( _pdriver, len( _pdriver ) - at( ",", _pdriver ) )

      // call method to change the container's printerName property,
      // if it's the SELPRINTERCONTAINER
      class::ItChanged()

   return

   function ItChanged
      // assign value to printerName property of SelPrinterContainer ...
      if this.parent.classname == "SELPRINTERCONTAINER"
         this.parent.PrinterName = this.value
      endif

endclass


