/*
   SaveEnvironment.prg

   Programmer...: Ken Mayer
   Date.........: April 5, 2002
   Notes........: Based on a request in the dBASE Newsgroups, this
                  is a function that should handle setup of the 
                  developer's environment using the INI class in
                  the dUFLP (which in turn uses some other classes,
                  see below).

                  This is part one of two parts ... 
                  This program was designed to take whatever
                  the settings for the Custom Form and Custom
                  Report in dB2K.ini and save them to the
                  current folder, in a file called Environment.ini

                  At the request of Bruce Beacham, this has
                  been enhanced to save the Function key 
                  settings, as SetEnvironment should restore
                  them ...

  Usage.........: Set the custom form and/or custom report
                  for the current working directory, and then
                  in the Command Window:

                  do :dUFLP:SaveEnvironment

  Misc. Notes...: This routine relies on the dUFLP source alias,
                  and the following:

                  INI.CC
                     StringEX.cc
                     SetProc.prg
*/

set procedure to :duflp:ini.cc additive

// First let's open the dB2K.ini and get values there:
oIDEINI = new ini( true ) // should invoke dB2K.ini
cSection = "FormDesigner"
cEntry   = "BaseFormClassFileName"
cCustFormFile = oIDEIni.GetValue( cSection, cEntry )
cEntry   = "BaseFormClassName"
cCustForm = oIDEIni.GetValue( cSection, cEntry )
cSection = "ReportDesigner"
cEntry   = "BaseReportClassFileName"
cCustReportFile = oIDEIni.GetValue( cSection, cEntry )
cEntry   = "BaseReportClassName"
cCustReport = oIDEIni.GetValue( cSection, cEntry )
oIDEIni.flush()
oIDEIni.release()

// Get the Function Key settings:
for i = 1 to 12
    cCmd = "cF"+i+" = setto( 'F"+i+"' )"
    &cCmd.
next

// uses *current* folder for environment.ini file
cPath = set("directory")
// if the file exists, we will be changing values
// in it ... otherwise this routine should create it
oEnvINI = new ini( cPath+"\environment.ini" )
cSection = "Custom"
cEntry   = "FormFile"
oEnvINI.SetValue( cSection, cEntry, cCustFormFile )
cEntry   = "Form"
oEnvINI.SetValue( cSection, cEntry, cCustForm )
cEntry   = "ReportFile"
oEnvINI.SetValue( cSection, cEntry, cCustReportFile )
cEntry   = "Report"
oEnvINI.SetValue( cSection, "Report", cCustReport )

// add function keys:
cSection = "FunctionKeys"
for i = 1 to 12
    cCmd = "oEnvINI.SetValue( cSection, 'F"+i+"', cF"+i+" )"
    &cCmd.
next

// On/Off and other environment settings based
// on some work by Gary White in a class called SaveEnv.cc:
cSection = "OnOffMisc"
cEntry = "Alternate"
oEnvINI.SetValue( cSection, cEntry, set("Alternate") )
cEntry = "AutoNullFields"
oEnvINI.SetValue( cSection, cEntry, set("AutoNullFields") )
cEntry = "AutoSave"
oEnvINI.SetValue( cSection, cEntry, set("AutoSave") )
cEntry = "Bell"
oEnvINI.SetValue( cSection, cEntry, set("Bell") )
cEntry = "BellTo"
oEnvINI.SetValue( cSection, cEntry, setto("Bell") )
cEntry = "BlockSizeTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Blocksize") )
cEntry = "Century"
oEnvINI.SetValue( cSection, cEntry, set("Century") )
cEntry = "Confirm"
oEnvINI.SetValue( cSection, cEntry, set("Confirm") )
cEntry = "Console"
oEnvINI.SetValue( cSection, cEntry, set("Console") )
cEntry = "Coverage"
oEnvINI.SetValue( cSection, cEntry, set("Coverage") )
cEntry = "CUAEnter"
oEnvINI.SetValue( cSection, cEntry, set("CUAEnter") )
cEntry = "Currency"
oEnvINI.SetValue( cSection, cEntry, set("Currency") )
cEntry = "CurrencyTo"
oEnvINI.SetValue( cSection, cEntry, setto("Currency") )
cEntry = "DatabaseTo"
oEnvINI.SetValue( cSection, cEntry, set("Database") )
cEntry = "Date"
oEnvINI.SetValue( cSection, cEntry, set("Date") )
cEntry = "DBTypeTo"
oEnvINI.SetValue( cSection, cEntry, set("DBType") )
cEntry = "Decimals"
oEnvINI.SetValue( cSection, cEntry, ""+set("Decimals") )
cEntry = "Deleted"
oEnvINI.SetValue( cSection, cEntry, set("Deleted") )
cEntry = "Design"
oEnvINI.SetValue( cSection, cEntry, set("Design") )
cEntry = "Development"
oEnvINI.SetValue( cSection, cEntry, set("Development") )
cEntry = "DirectoryTo"
oEnvINI.SetValue( cSection, cEntry, set("Directory") )
cEntry = "EditorTo"
oEnvINI.SetValue( cSection, cEntry, set("Editor") )
cEntry = "Encryption"
oEnvINI.SetValue( cSection, cEntry, set("Encryption") )
cEntry = "EpochTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Epoch") )
cEntry = "ErrorTo"
oEnvINI.SetValue( cSection, cEntry, set("Error") )
cEntry = "Escape"
oEnvINI.SetValue( cSection, cEntry, set("Escape") )
cEntry = "Exact"
oEnvINI.SetValue( cSection, cEntry, set("Exact") )
cEntry = "Exclusive"
oEnvINI.SetValue( cSection, cEntry, set("Exclusive") )
cEntry = "Fields"
oEnvINI.SetValue( cSection, cEntry, set("Fields") )
cEntry = "FieldsTo"
oEnvINI.SetValue( cSection, cEntry, setto("Fields") )
cEntry = "FullPath"
oEnvINI.SetValue( cSection, cEntry, set("FullPath") )
cEntry = "Headings"
oEnvINI.SetValue( cSection, cEntry, set("Headings") )
cEntry = "HoursTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Hours") )
cEntry = "IBlockTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("IBLOCK") )
cEntry = "LDCheck"
oEnvINI.SetValue( cSection, cEntry, set("LDCheck") )
cEntry = "LDConvert"
oEnvINI.SetValue( cSection, cEntry, set("LDConvert") )
cEntry = "Lock"
oEnvINI.SetValue( cSection, cEntry, set("Lock") )
cEntry = "MarginTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Margin") )
cEntry = "MarkTo"
oEnvINI.SetValue( cSection, cEntry, set("Mark") )
cEntry = "MBlockTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("MBlock") )
cEntry = "MessageTo"
oEnvINI.SetValue( cSection, cEntry, set("Message") )
cEntry = "Near"
oEnvINI.SetValue( cSection, cEntry, set("Near") )
cEntry = "OdometerTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Odometer") )
cEntry = "PathTo"
oEnvINI.SetValue( cSection, cEntry, set("Path") )
cEntry = "PointTo"
oEnvINI.SetValue( cSection, cEntry, set("Point") )
cEntry = "PrecisionTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Precision") )
cEntry = "RefreshTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Refresh") )
cEntry = "ReprocessTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Reprocess") )
cEntry = "Safety"
oEnvINI.SetValue( cSection, cEntry, set("Safety") )
cEntry = "SeparatorTo"
oEnvINI.SetValue( cSection, cEntry, set("Separator") )
cEntry = "Space"
oEnvINI.SetValue( cSection, cEntry, set("Space") )
cEntry = "Talk"
oEnvINI.SetValue( cSection, cEntry, set("Talk") )
cEntry = "Title"
oEnvINI.SetValue( cSection, cEntry, set("Title") )
cEntry = "TypeaheadTo"
oEnvINI.SetValue( cSection, cEntry, ""+set("Typeahead") )
cEntry = "Unique"
oEnvINI.SetValue( cSection, cEntry, set("Unique") )
cEntry = "SpeedBar"
oEnvINI.SetValue( cSection, cEntry, ""+_app.SpeedBar )
cEntry = "StatusBar"
oEnvINI.SetValue( cSection, cEntry, ""+_app.StatusBar )

// done, save it all and release the INI object:
oEnvINI.flush()
oEnvINI.release()

? "Environment saved ..."

close procedure :dUFLP:ini.cc

/*
   End of program: SaveEnvironment.prg
*/
